@@ -11,6 +11,7 @@ import json
 import logging
 import urllib
 import urllib2
+import time
 
 log = logging.getLogger(__name__)
 
@@ -111,6 +112,18 @@ class Controller:
         params = urllib.urlencode({'json': js})
         return self._read(self.api_url + 'list/alarm', params)
 
+    def get_statistics_last_24h(self):
+        """Returns statistical data of the last 24h"""
+
+        return self.get_statistics_24h(time.time())
+        
+    def get_statistics_24h(self, endtime):
+        """Return statistical data last 24h from time"""
+        
+        js = json.dumps({'attrs':["bytes","num_sta","time"], 'start':int(endtime-86400)*1000, 'end':int(endtime-3600)*1000})
+        params = urllib.urlencode({'json': js})
+        return self._read(self.api_url + 'stat/report/hourly.system', params)
+        
     def get_events(self):
         """Return a list of all Events."""
 
